@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 from enum import Enum
-from typing import List, Set
+from typing import Dict, List, Set
 
 from .mod_loaders import ModLoaders
 from .sites import Sites
@@ -30,8 +30,10 @@ class VersionInfo:
         upload_time: int,
         minecraft_versions: List[str],
         download_url: str,
+        number: str,
         filename: str = "",
-        name: str = "",
+        mod_name: str = "",
+        dependencies: Dict[Sites, List[str]] = {},
     ) -> None:
         self.stability = stability
         self.mod_loaders = mod_loaders
@@ -39,8 +41,10 @@ class VersionInfo:
         self.upload_time = upload_time
         self.minecraft_versions = minecraft_versions
         self.download_url = download_url
+        self.number = number
         self.filename = filename
-        self.name = name
+        self.name = mod_name
+        self.dependencies = dependencies
 
     def __str__(self) -> str:
         return f"{self.minecraft_versions}; uploaded {self.upload_time}"
@@ -56,8 +60,10 @@ class VersionInfo:
             self.upload_time,
             self.minecraft_versions,
             self.download_url,
+            self.number,
             self.filename,
             self.name,
+            self.dependencies,
         )
 
     def __eq__(self, other) -> bool:
